from typing import Final

DEFAULT_HEADERS: Final[str] = {'User-Agent': 'Mozilla/5.0 (iPhone; CPU iPhone OS 16_6 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/16.6 Mobile/15E148 Safari/604.1'}
DEFAULT_PARSER: Final[str] = 'html.parser'